## FITK - the Fisher Information ToolKit
[![codecov](https://codecov.io/gh/JCGoran/fitk/branch/master/graph/badge.svg?token=NX9WRX89SI)](https://codecov.io/gh/JCGoran/fitk)
[![CircleCI](https://dl.circleci.com/status-badge/img/gh/JCGoran/fitk/tree/master.svg?style=shield&circle-token=5cc8653735b0092318b9790720101eaa4c568c10)](https://dl.circleci.com/status-badge/redirect/gh/JCGoran/fitk/tree/master)
[![python - versions](https://img.shields.io/pypi/pyversions/fitk)](https://pypi.org/project/fitk/)
[![CodeFactor](https://www.codefactor.io/repository/github/jcgoran/fitk/badge)](https://www.codefactor.io/repository/github/jcgoran/fitk)

Fitk is a Python package for computing, manipulating, and plotting of Fisher information matrices.

### Installation

The best way to install the stable version is via `pip`:

```plaintext
pip install fitk
```

Note that on some systems you may have to replace `pip` by `python3 -m pip` or similar for the installation.
Furthermore, if you only wish to install the package for the current user (or don't have root privileges), you should supply the `--user` flag to the above command.

Alternatively, if you want to install the latest development version:

```plaintext
pip install git+https://github.com/JCGoran/fitk
```

### Usage

For various examples on how to use FITK, as well as the latest API, please refer to [the main docs](https://jcgoran.github.io/fitk/).

### Issues

If you encounter any bugs running the code, or have a suggestion for new functionality, please open up a new issue [on GitHub](https://github.com/JCGoran/fitk/issues/).

### Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md).

### License

See [LICENSE](LICENSE) file.
